Learn R Programming

mvabund (version 4.1.12)

deviance.manylm: Model Deviance

Description

Returns the deviance of a fitted multivariate model object for abundance data.

Usage


# S3 method for manylm
deviance(object, na.action="na.omit", …)

Arguments

object

the manylm object.

na.action

how to deal with NA values. Can be one of "na.omit", "na.exclude", "na.fail", NULL

…

additional optional arguments.

Value

The value of the deviance extracted from the object object.

See Also

manylm.

Examples

Run this code
# NOT RUN {
data(spider)
spiddat <- mvabund(spider$abund)
X <- spider$x

## Calculate the deviance:
deviance(manylm(spiddat~X))
# }

Run the code above in your browser using DataLab