Usage
manylm.fit(x, y, offset = NULL, tol=1.0e-010, singular.ok = TRUE, ...)
manylm.wfit(x, y, w, offset = NULL, tol=1.0e-010, singular.ok = TRUE, ...)
Arguments
x
design matrix of dimension n * p.
y
matrix or an mvabund object of observations of dimension n*q.
w
vector of weights (length n) to be used in the fitting
process for the manylm.wfit functions. Weighted least squares is
used with weights w, i.e., sum(w * e^2) is minimized.
offset
numeric of length n). This can be used to
specify an a priori known component to be included in the
linear predictor during fitting.
tol
tolerance for the qr decomposition. Default
is 1.0e-050.
singular.ok
logical. If FALSE, a singular model is an
error.
...
currently disregarded.