refs
a vector specifying validation group membership. Default is to
construct refs using a method that is a function of the sample size N:
if N<=20< code="">, leave-one-out is used refs=1:N, if N<=40< code="">,
10-fold Cross Validation is used where group membership is chosen randomly
but with equal size groups, otherwise 5-fold CV with random group memberships.
=40<>=20<>