This function is similar to jitter but is defines for points in
a two-dimensional plot. In contrast to jitter only the points with ties
have a shift different from 0. The method to calculate the shift is therefore
not based on random numbers.
If method=1 (default) the individual shift will be selected so that the
shift range is sh, without regard of the number of overlapping points method=2 means that for up to reg overlapping values a fixed
shift of sh/reg is used